from setuptools import setup
setup(name='cso_data',
version='0.1.01',
description='A handy tool to get cso data in python',
url='https://github.com/Aidzillafont/cso_app',
author='Aidzillafont',
author_email='aheffernan0@gmail.com',
license='MIT',
packages=['cso_data'],
long_description=open('README.md').read(),
zip_safe=False)


